@@ -44,7 +44,7 @@ Usage:
 
 Arguments for detect:
     contact_map                 The Hi-C contact map to detect patterns on, in
-                                bedgraph2d or cool format.
+                                cool format.
     prefix                      Common path prefix used to generate output files.
                                 Extensions will be added for each file.
 
@@ -52,8 +52,7 @@ Arguments for quantify:
     bed2d                       Tab-separated text files with columns chrom1, start1
                                 end1, chrom2, start2, end2. Each line correspond to
                                 a pair of positions (i.e. a position in the matrix).
-    contact_map                 Path to the contact map, in bedgraph2d or
-                                cool format.
+    contact_map                 Path to the contact map, in cool format.
     prefix                      Common path prefix used to generate output files.
                                 Extensions will be added for each file.
 
@@ -841,7 +840,7 @@ def cmd_detect(args):
     del min_dist_drop_mask
 
     # Remove patterns with nan p-values (no contact in window)
-    pval_mask = np.isnan(all_coords.pvalue)
+    pval_mask = all_coords.pvalue.isnull()
     all_coords = all_coords.loc[~pval_mask, :]
     all_windows = all_windows[~pval_mask, :, :]
     del pval_mask
